[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - pywurfl.serialize.Serialize
  - pywurfl.algorithms.Algorithm: Base class for all pywurfl search algorithms
    - pywurfl.algorithms.Tokenizer: Tokenizer Search Algorithm
    - pywurfl.algorithms.LevenshteinDistance: Levenshtein distance Search Algorithm
    - pywurfl.algorithms.JaroWinkler: Jaro-Winkler Search Algorithm
  - pywurfl.wurflprocessor.DeviceHandler: Base class for DeviceHandler objects
    - wurfl2python.DeviceSerializer
  - pywurfl.RootDevice: pywurfl Root Device base class.
  - pywurfl.Devices: Main pywurfl API class.
  - pywurfl.wurflprocessor.WurflProcessor: WURFL Processing Class
    - wurfl2python.WurflPythonWriter
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - pywurfl.exceptions.WURFLException: pywurfl base exception class.
        - pywurfl.wurflprocessor.DeferredDeviceError: Deferred Device Error Exception
        - pywurfl.exceptions.DeviceNotFound: Device Not Found exception class
        - pywurfl.exceptions.ActualDeviceRootNotFound: Actual Device Root Not Found exception class
        - pywurfl.ql.QueryLanguageError: Base exception class for pywurfl.ql
        - pywurfl.exceptions.ExistsException: General exception class
- pywurfl.ql._Type
  - pywurfl.ql.TypeNone
  - pywurfl.ql.TypeList
  - pywurfl.ql.TypeStr
  - pywurfl.ql.TypeNum
  - pywurfl.ql.TypeBool